@@ -48,6 +48,14 @@ def _context_check_variable(context, var_name, needed_by):
                                    " needed for '%s'" % (var_name, needed_by))
 
 
+def _context_fetch_source(context, url):
+    """fetch the given url into the output_dir and return the url"""
+    if context['output_dir']:
+        filename = os.path.basename(url)
+        utils._download_file(url, context['output_dir'], filename)
+    return url
+
+
 def _context_upstream_version(context, pkg_version=None):
     """return the version which should be set to the 'upstream_version'
     variable in the jinja context"""
@@ -58,10 +66,14 @@ def _context_upstream_version(context, pkg_version=None):
         _context_check_variable(context, CONTEXT_VAR_PYPI_NAME,
                                 'upstream_version')
         pypi_name = context.vars[CONTEXT_VAR_PYPI_NAME]
-        # look for archives in the dir where the input template (.spec.j2)
-        # comes from. As fallback, also look in the current working dir
-        archives = utils._find_archives([context['input_template_dir'], '.'],
-                                        pypi_name)
+
+        # look for archives in:
+        # 1) the output_dir
+        # 2) the dir where the input template (.spec.j2) comes from
+        # 3) the current working dir
+        archives = utils._find_archives([context['output_dir'],
+                                         context['input_template_dir'],
+                                         '.'], pypi_name)
         for archive in archives:
             with utils._extract_archive_to_tempdir(archive) as tmpdir:
                 pkg_info_file = utils._find_pkg_info(tmpdir)
@@ -213,6 +225,11 @@ def _globals_py2pkg(context, pkg_name, pkg_version=None):
     return _context_py2pkg(context, pkg_name, pkg_version)
 
 
+@contextfunction
+def _globals_fetch_source(context, url):
+    return _context_fetch_source(context, url)
+
+
 @contextfunction
 def _globals_upstream_version(context, pkg_version=None):
     return _context_upstream_version(context, pkg_version)
@@ -253,9 +270,11 @@ def _env_register_filters_and_globals(env):
     env.globals['epoch'] = _globals_epoch
     env.globals['license'] = _globals_license_spdx
     env.globals['upstream_version'] = _globals_upstream_version
+    env.globals['fetch_source'] = _globals_fetch_source
 
 
-def generate_spec(spec_style, epochs, requirements, input_template_path):
+def generate_spec(spec_style, epochs, requirements, input_template_path,
+                  output_path):
     """generate a spec file with the given style and the given template"""
 
     env = Environment(loader=RenderspecLoader(
@@ -269,9 +288,15 @@ def generate_spec(spec_style, epochs, requirements, input_template_path):
         template_name = spec_style
     template = env.get_template(template_name)
     input_template_dir = os.path.dirname(os.path.abspath(input_template_path))
+    if output_path:
+        output_dir = os.path.dirname(
+            os.path.abspath(output_path))
+    else:
+        output_dir = None
     return template.render(spec_style=spec_style, epochs=epochs,
                            requirements=requirements,
-                           input_template_dir=input_template_dir)
+                           input_template_dir=input_template_dir,
+                           output_dir=output_dir)
 
 
 def _is_fedora(distname):
@@ -372,11 +397,17 @@ def main():
     except IOError as e:
         print(e)
         return 3
-    spec = generate_spec(args['spec_style'], epochs, requirements,
-                         input_template)
+
     if output_fn and output_fn != '-':
-        print("Rendering: %s -> %s" % (input_template, output_fn))
-        with open(output_fn, "w") as o:
+        output_path = os.path.abspath(output_fn)
+    else:
+        output_path = None
+
+    spec = generate_spec(args['spec_style'], epochs, requirements,
+                         input_template, output_path)
+    if output_path:
+        print("Rendering: %s -> %s" % (input_template, output_path))
+        with open(output_path, "w") as o:
             o.write(spec)
     else:
         print(spec)
