@@ -110,6 +110,23 @@ class RenderspecContextFunctionTests(unittest.TestCase):
         self.assertEqual(renderspec._context_upstream_version(
                 context, '1.2.0'), '1.2.0')
 
+    @data(
+        # no output_dir -> download_files should not be called
+        (None, 0),
+        # output_dir defined -> download_files should be called once
+        ('.', 1)
+    )
+    @unpack
+    def test_context_fetch_source_no_output_dir(self, output_dir,
+                                                expected_calls):
+        context = {'spec_style': 'suse', 'epochs': {},
+                   'requirements': {}, 'output_dir': output_dir}
+        url = 'http://foo/bar'
+        with patch('renderspec.utils._download_file') as m:
+            self.assertEqual(renderspec._context_fetch_source(
+                context, url), url)
+            self.assertEqual(m.call_count, expected_calls)
+
 
 @ddt
 class RenderspecTemplateFunctionTests(unittest.TestCase):
@@ -338,11 +355,11 @@ class RenderspecCommonTests(unittest.TestCase):
                            expected_result):
         tmpdir = tempfile.mkdtemp(prefix='renderspec-test_')
         try:
-            f1 = os.path.join(tmpdir, 'test.spec')
+            f1 = os.path.join(tmpdir, 'test.spec.j2')
             with open(f1, 'w+') as f:
                 f.write(template)
             rendered = renderspec.generate_spec(
-                style, epochs, requirements, f1)
+                style, epochs, requirements, f1, None)
             self.assertEqual(rendered, expected_result)
         finally:
             shutil.rmtree(tmpdir)
@@ -405,7 +422,8 @@ class RenderspecDistTeamplatesTests(unittest.TestCase):
             # mock this to use testing dist-tempaltes folder
             mock_dt_path.return_value = dt_dir
 
-            out = renderspec.generate_spec('loldistro', {}, {}, base_path)
+            out = renderspec.generate_spec('loldistro', {}, {}, base_path,
+                                           None)
             self.assertEqual(out, expected_out)
         finally:
             shutil.rmtree(tmpdir)
@@ -448,12 +466,12 @@ class RenderspecUtilsTests(unittest.TestCase):
         finally:
             shutil.rmtree(tmpdir)
 
-    def _test__version_from_pkg_info(self):
+    def test__version_from_pkg_info(self):
         tmpdir = tempfile.mkdtemp(prefix='renderspec-test_')
         version = '5.10.0'
         try:
             self._write_pkg_info(tmpdir, version)
-            pkg_info_file = renderspec.utils._find_pkg_info(tmpdir),
+            pkg_info_file = renderspec.utils._find_pkg_info(tmpdir)
             self.assertEqual(
                 renderspec.utils._get_version_from_pkg_info(pkg_info_file),
                 version
@@ -467,7 +485,7 @@ class RenderspecUtilsTests(unittest.TestCase):
         (['foo-1.2.3.tar.gz'], 'bar', []),
     )
     @unpack
-    def _test__find_archives(self, archives, pypi_name, expected):
+    def test__find_archives(self, archives, pypi_name, expected):
         tmpdir = tempfile.mkdtemp(prefix='renderspec-test_')
         try:
             for a in archives:
@@ -479,19 +497,23 @@ class RenderspecUtilsTests(unittest.TestCase):
         finally:
             shutil.rmtree(tmpdir)
 
-    def _test__find_archives_multiple_dirs(self):
+    def test__find_archives_multiple_dirs(self):
         tmpdir1 = tempfile.mkdtemp(prefix='renderspec-test_')
         tmpdir2 = tempfile.mkdtemp(prefix='renderspec-test_')
         try:
             open(os.path.join(tmpdir2, 'foo-1.2.3.tar.xz'), 'w').close()
             self.assertEqual(
-                renderspec.utils._find_archives([tmpdir1, tmpdir2], 'foo'),
+                renderspec.utils._find_archives([None, tmpdir1, tmpdir2],
+                                                'foo'),
                 ['foo-1.2.3.tar.xz']
             )
         finally:
             shutil.rmtree(tmpdir1)
             shutil.rmtree(tmpdir2)
 
+    def test__find_archives_only_no_dir(self):
+        self.assertEqual(renderspec.utils._find_archives([None], 'foo'), [])
+
 
 if __name__ == '__main__':
     unittest.main()
